@@ -1,12 +1,12 @@
-#' Extract coefficients 
-#' 
-#' Extract coefficients and provide a summary of parameters and estimates from the output of
-#' \code{\link{ddf}} model objects.
-#' 
+#' Extract coefficients
+#'
+#' Extract coefficients and provide a summary of parameters and estimates
+#' from the output of \code{\link{ddf}} model objects.
+#'
 #' @aliases coefficients coef.ds coef.io coef.io.fi coef.trial coef.trial.fi
-#'   coef.rem coef.rem.fi 
-#' @param object ddf model object of class "ds", "io", "io.fi", "trial",
-#'   "trial.fi", "rem", or "rem.fi"
+#'   coef.rem coef.rem.fi
+#' @param object ddf model object of class \code{ds}, \code{io}, \code{io.fi},
+#'    \code{trial}, \code{trial.fi}, \code{rem}, or \code{rem.fi}.
 #' @param \dots unspecified arguments that are unused at present
 #' @usage \method{coef}{ds}(object,...)
 #'        \method{coef}{io}(object,...)
@@ -23,37 +23,39 @@
 #' @S3method coef rem
 #' @S3method coef rem.fi
 #' @return
-#' 
+#'
 #' For \code{coef.ds} List of data frames for coefficients (scale and exponent
 #'   (if hazard)) \item{scale}{dataframe of scale coefficent estimates and
 #'   standard errors} \item{exponent}{dataframe with exponent estimate and
 #'   standard error if hazard detection function}
-#' 
+#'
 #' For all others Data frame containing each coefficient and standard error
 #' @note These functions are called by the generic function \code{coef} for any
 #'   \code{ddf} model object.  It can be called directly by the user, but it is
 #'   typically safest to use \code{coef} which calls the appropriate function
 #'   based on the type of model.
-#' @author Jeff Laake; 
-coef.ds <- function(object,...) {
+#' @author Jeff Laake;
+coef.ds <- function(object,...){
   ltmodel <- object$ds
   coeff <- NULL
-  if(is.null(object$par))
-	  vcov <- NULL
-  else
-      vcov <- solvecov(object$hessian)$inv
-  #vcov=matrix(1,nrow=nrow(model$hessian),ncol=nrow(model$hessian))
+  if(is.null(object$par)){
+    vcov <- NULL
+  }else{
+    vcov <- solvecov(object$hessian)$inv
+  }
 
   ddfobj <- ltmodel$aux$ddfobj
   indices <- getpar(ddfobj,index=TRUE)
   se <- sqrt(diag(vcov))
 
   if(indices[1]!=0){
-	  key.shape.se <- se[1:indices[1]]
+    key.shape.se <- se[1:indices[1]]
   }
+
   if(indices[2]!=0){
     key.scale.se <- se[(indices[1]+1):indices[2]]
   }
+
   if(indices[3]!=0){
     if(indices[2]!=0){
       adj.parm.se <- se[(indices[2]+1):indices[3]]
@@ -75,7 +77,7 @@ coef.ds <- function(object,...) {
                                      se=key.shape.se))
     row.names(exp.coeff) <- colnames(ddfobj$shape$dm)
   }
-  
+
   # Get the adjustment parameters if necessary
   if(!is.null(ddfobj$adjustment)){
     adj.coeff <- as.data.frame(cbind(estimate=ddfobj$adjustment$parameters,
@@ -91,49 +93,17 @@ coef.ds <- function(object,...) {
     if(!is.null(ddfobj$shape)){
       return(list(scale=coeff,exponent=exp.coeff,adjustment=adj.coeff))
     }else if(is.null(ddfobj$scale)){
-		  return(list(adjustment=adj.coeff))
-	  }else{  
-		  return(list(scale=coeff,adjustment=adj.coeff))
+      return(list(adjustment=adj.coeff))
+    }else{
+      return(list(scale=coeff,adjustment=adj.coeff))
     }
 
   }
 
   # Return values if no adjustment terms
   if(!is.null(ddfobj$shape)){
-		return(list(scale=coeff,exponent=exp.coeff))
+    return(list(scale=coeff,exponent=exp.coeff))
   }else{
     return(list(scale=coeff))
   }
 }
-
-
-
-# solvecov code was taken from package fpc: Christian
-# Hennig chrish@@stats.ucl.ac.uk http://www.homepages.ucl.ac.uk/~ucakche/
-solvecov <- function (m, cmax = 1e+10){
-  options(show.error.messages = FALSE)
-  covinv <- try(solve(m))
-  if(class(covinv) != "try-error"){
-    coll = FALSE
-  }else{
-    p <- nrow(m)
-    cove <- eigen(m, symmetric = TRUE)
-    coll <- TRUE
-    if(min(cove$values) < 1/cmax) {
-      covewi <- diag(p)
-      for (i in 1:p){
-        if (cove$values[i] < 1/cmax){
-          covewi[i, i] <- cmax
-        }else{
-         covewi[i, i] <- 1/cove$values[i]
-        }
-      }
-    }else{
-      covewi <- diag(1/cove$values, nrow = length(cove$values))
-    }
-    covinv <- cove$vectors %*% covewi %*% t(cove$vectors)
-  }
-  options(show.error.messages = TRUE)
-  out <- list(inv = covinv, coll = coll)
-  return(out)
-}
